import { Component, Input, OnChanges, OnInit, SimpleChanges, ViewChild } from "@angular/core";

import { CollectionView, format, SortDescription } from "@grapecity/wijmo";
import { Column, FlexGrid } from "@grapecity/wijmo.grid";

@Component({
  selector: 'app-grid',
  templateUrl: './grid.component.html',
  styleUrls: ['./grid.component.css']
})
export class GridComponent {
  @Input() data: any = null;

  selectedItem?: string;
  gridData: CollectionView;
  // references FlexGrid named 'flex' in the view
  @ViewChild('flex', { static: true }) flex?: FlexGrid;

  // DataSvc will be passed by derived classes
  constructor() {
    this.gridData = new CollectionView();
  }

  ngOnInit(): void {
  }

  ngOnChanges(changes: SimpleChanges): void {
    if (changes['data']) {
      this.gridData.sourceCollection = changes['data'].currentValue;
    }
  }

  flexInitialized(flexgrid: FlexGrid) {
    // sort the data by country
    const sd = new SortDescription('country', true);
    flexgrid.collectionView.sortDescriptions.push(sd);
    flexgrid.collectionView.currentChanged.addHandler(this._updateCurrentInfo.bind(this));
    this._updateCurrentInfo();

    const columns = 'country,sales,expenses'.split(',')
    for (let i = 0; i < columns.length; i++) {
      // this.flex?.columns.push(this.mapColumn(columns[i]));
    }

  }

  private _getData() {
    // create some random data
    const countries = 'US,Germany,UK,Japan,Italy,Greece'.split(','),
      data = [];
    for (let i = 0; i < countries.length; i++) {
      data.push({
        id: i,
        country: countries[i],
        sales: Math.random() * 10000,
        expenses: Math.random() * 5000
      });
    }

    return data;
  }

  private _updateCurrentInfo() {
    this.selectedItem = format(
      'Country: <b>{country}</b>, Sales: <b>{sales:c0}</b> Expenses: <b>{expenses:c0}</b>',
      this.flex?.collectionView.currentItem);
  }

  private mapColumn(columnName: string): Column {
    return new Column({
      name: columnName,
      binding: columnName,
    });
  }
}
